from tdf_tools.tools.config.initial_json_config import InitialJsonConfig
from tdf_tools.tools.cmd import Cmd
from tdf_tools.tools.print import Print
from tdf_tools.tools.shell_dir import ShellDir


class Git:
    """
    tdf_tools git【git 命令】：批量操作 git 命令, 例如 tdf_tools git push
    """

    def __init__(self, arg: list):
        self.__arg = ["git"] + arg

    def run(self):
        ShellDir.dirInvalidate()
        self.__batch_run_git()

    def __batch_run_git(self):
        for module in InitialJsonConfig().moduleNameList:
            ShellDir.goInModuleDir(module)
            Print.title("开始操作" + module + "模块：" + " ".join(self.__arg))
            Cmd.runAndPrint(self.__arg, shell=False)



import os
import platform
import shutil
import stat


class FlutterScript(object):

    def __init__(self):
        self.isWindow = platform.system().lower() == 'windows'
        self.osTargetCommand = ''
        if (self.isWindow):
            self.osTargetCommand = 'cd'
        else:
            self.osTargetCommand = 'pwd'

    def readonly_handler(func, path, execinfo):
        os.chmod(path, stat.S_IWRITE)
        func(path)

    def execFunc(self, scriptFile, moduleName):
        os.system(
            'git clone git@git.2dfire.net:app/flutter/tools/flutter-script.git')

        print('执行脚本：' + scriptFile)
        print('模块：' + moduleName)
        print('python3 flutter-script/{0} {1}'.format(scriptFile, moduleName))
        os.system(
            'python3 flutter-script/{0} {1}'.format(scriptFile, moduleName))
        if (self.isWindow):
            path = os.popen(self.osTargetCommand).read().split('\n')[0]
            path = path + "\\flutter-script"
            shutil.rmtree(path, ignore_errors=False,
                          onerror=self.readonly_handler)
        else:
            shutil.rmtree(r'flutter-script')



import json
import os
from tdf_tools.tools.config.initial_json_config import InitialJsonConfig
from tdf_tools.tools.config.module_json_config import ModuleItemType, ModuleJsonConfig
from tdf_tools.tools.regular_tool import RegularTool
from tdf_tools.tools.shell_dir import ShellDir
from tdf_tools.tools.print import Print


class TranslateLintInil:
    def __init__(self, file_path: str, un_intl_strs: list[str]):
        # 未国际化文件路径
        self.file_path = file_path
        # 文件中没有国际化的字符串
        self.un_intl_strs = un_intl_strs


class TranslateLintApostrophe:
    def __init__(self, file_path: str, apostrophe_strs: list[str]):
        # 单引号文件路径
        self.file_path = file_path
        # 单引号的字符串
        self.apostrophe_strs = apostrophe_strs


class TranslateLintImport:
    def __init__(self, file_path: str, import_strs: list[str]):
        # import 错误的文件路径
        self.file_path = file_path
        # import 错误的字符串
        self.import_strs = import_strs


class TranslateLintResult:
    def __init__(
        self,
        un_intls: list[TranslateLintInil],
        intl_strs: list[str],
        intl_json: list[str],
        imports: list[TranslateLintImport],
        apostrophes: list[TranslateLintApostrophe],
    ):
        # 没有使用 .intl 修饰的中文字符串
        self.un_intls = un_intls
        # 使用 .intl 修饰的中文字符串
        self.intl_strs = intl_strs
        # i18n.json 中没用到的国际化字符串
        self.intl_json = intl_json
        # 不符合规范的 import
        self.imports = imports
        # 单引号字符串
        self.apostrophes = apostrophes


class TranslateLint:
    """
    国际化相关：检测源码中是否还有没国际化的文案
    """

    def start(self):
        """
        以交互的方式选择需要 lint 的模块
        """
        ShellDir.dirInvalidate()
        businessModuleList = self.businessModuleList()
        Print.str("检测到以下模块可执行国际化lint：")
        Print.str(businessModuleList)
        inputStr = input("请输入需要执行 lint 的模块名(input ! 退出, all 全选)：")
        if inputStr == "!" or inputStr == "！":
            exit(0)
        elif inputStr == "all":
            self.__lint_all()
            exit(0)
        elif inputStr in businessModuleList:
            self.module(inputStr)
            exit(0)

    def module(self, name: str):
        """
        指定模块 lint
        """
        ShellDir.dirInvalidate()
        result = self.get_lint_module_result(name)
        if self.__lint_result(result):
            Print.stage(name + " 模块国际化 lint 通过")
        else:
            Print.error(name + " 模块国际化 lint 失败")

    def path(self, path: str):
        """
        指定模块路径 lint，路径为 lib 路径
        """
        result = self.__lint_intl_path(path)
        if self.__lint_result(result):
            Print.title(path + " 路径国际化 lint 通过")
        else:
            Print.error(path + " 路径国际化lint 失败")

    def get_lint_module_result(self, module_name: str) -> TranslateLintResult:
        print("\n")
        Print.title(module_name + " 模块国际化 lint 开始执行")
        target_path = ShellDir.getModuleLibDir(module_name)
        if os.path.exists(target_path):
            return self.__lint_intl_path(target_path)
        else:
            Print.error(target_path + "路径不存在")

    def __lint_all(self):
        results = []
        pass_result = True
        for module in self.businessModuleList():
            result = self.get_lint_module_result(module)
            results.append(result)
            if not self.__lint_result(result):
                pass_result = False
                Print.error(module + " 模块国际化 lint 失败", shouldExit=False)
            else:
                Print.title(module + " 模块国际化 lint 成功")

        if pass_result:
            print("\n")
            Print.title("国际化 lint 通过")
        else:
            Print.error("国际化 lint 失败")

    # 指定路径 lint，path 的必须是 lib 文件
    def __lint_intl_path(self, path: str) -> TranslateLintResult:
        # 没有使用 .intl 修饰的中文字符串
        un_intls = []
        # 使用 .intl 修饰的中文字符串
        intl_strs = []
        # 所有的 dart 文件路径
        dart_files = []
        # 使用单引号的字符串
        apostrophes = []

        # 不符合的 imports
        imports = []
        module_name = ShellDir.getModuleNameFromYaml(path + "/../pubspec.yaml")
        right_import = self.get_module_import_str(module_name)

        i18n_json: dict = self.__get_i18n_json(path)
        Print.stage("lint 路径：" + path)
        for root, __, files in os.walk(path):
            for file in files:
                # 过滤掉 tdf_intl 目录下的 dart 文件
                if (
                    file.endswith(".dart")
                    and not root.__contains__("/tdf_intl/")
                    and not file.endswith(".tdf_router.dart")
                ):
                    dart_files.append(root + "/" + file)
        for file in dart_files:
            f = open(file)
            file_content = f.read()
            file_content = RegularTool.delete_remark(file_content)
            # 所有的 intl import
            all_imports = RegularTool.find_intl_imports(file_content)
            # 错误的 intl import
            err_imports = list(filter(lambda x: x != right_import, all_imports))
            if len(err_imports) > 0:
                un_import = TranslateLintImport(file, err_imports)
                imports.append(un_import)

            # lines = file_content.splitlines()
            # file_content = "".join(lines)
            file_content = RegularTool.delete_track(file_content)
            file_content = RegularTool.delete_router(file_content)
            file_content = RegularTool.delete_deprecated(file_content)
            # 寻找单引号字符串
            apostrophe_strs = RegularTool.find_apostrophe_strs(file_content)
            if len(apostrophe_strs) > 0:
                apostrophe = TranslateLintApostrophe(file, apostrophe_strs)
                apostrophes.append(apostrophe)

            # 寻找加上 .intl 的文案，并删除掉，以免影响 下面的操作
            _intl_strs = RegularTool.find_intl_str(file_content)
            intl_strs += _intl_strs
            file_content = RegularTool.delete_intl_str(file_content)
            # 寻找没有国际化的 文案
            _un_intl_strs = RegularTool.find_chinese_str(file_content)
            if len(_un_intl_strs) > 0:
                un_intl = TranslateLintInil(file, _un_intl_strs)
                un_intls.append(un_intl)
            f.close()

        # intl_strs 去重
        intl_strs = list(set(intl_strs))
        new_intl_strs = []
        # 对比加上 .intl 的文案 和 i18n_json里面的差异
        i18n_json_keys = list(i18n_json.keys())
        for key in intl_strs:
            # 因为正则出来的带转义符，必须去掉转义符后对比
            key = RegularTool.decode_escapes(key)
            if key in i18n_json_keys:
                i18n_json_keys.remove(key)
            else:
                new_intl_strs.append(key)

        return TranslateLintResult(
            un_intls, new_intl_strs, i18n_json_keys, imports, apostrophes
        )

    # 获取 i8n.json 的数据
    def __get_i18n_json(self, path: str) -> dict[str:str]:
        target_path = path + "/tdf_intl/i18n.json"
        if os.path.exists(target_path):
            with open(target_path, "r", encoding="utf-8") as json_file:
                json_str = json_file.read()
                json_dict = json.loads(json_str)
                return json_dict
        else:
            return {}

    # 校验 lint 的结果
    def __lint_result(self, result: TranslateLintResult) -> bool:

        if len(result.apostrophes) > 0:
            Print.warning("使用到了单引号字符串，请统一修改为双引号")
            for i in result.apostrophes:
                file_name = i.file_path.split(r"/")[-1]
                Print.title(file_name + " 文件中有以下未国际化的字符串：")
                Print.str(i.apostrophe_strs)

        if len(result.intl_json) > 0:
            Print.warning("i18n.json 中有以下字符串没有使用到：")
            Print.str(result.intl_json)

        if len(result.intl_strs) > 0:
            Print.warning("以下 .intl 修饰的字符串没有添加到 i18n.json 中：")
            Print.str(result.intl_strs)

        if len(result.un_intls) > 0:
            Print.warning("以下文件中有没国际化的中的字符串：")
            for i in result.un_intls:
                file_name = i.file_path.split(r"/")[-1]
                Print.title(file_name + " 文件中有以下未国际化的字符串：")
                Print.str(i.un_intl_strs)

        if len(result.imports) > 0:
            Print.warning("以下文件中有没不符合规范的 import ：")
            for i in result.imports:
                file_name = i.file_path.split(r"/")[-1]
                Print.title(file_name + " 文件中有以下未国际化的字符串：")
                Print.str(i.import_strs)

        return (
            len(result.un_intls) == 0
            and len(result.intl_json) == 0
            and len(result.intl_strs) == 0
            and len(result.imports) == 0
            and len(result.apostrophes) == 0
        )

    # 获取模块正确的 import 语句
    def get_module_import_str(self, module_name: str) -> str:
        return "import 'package:{name}/tdf_intl/{name}_i18n.dart';".format(
            name=module_name
        )

    # 可以进行国际化的列表
    def businessModuleList(self) -> list:
        self.__initialConfig = InitialJsonConfig()
        self.__moduleConfig = ModuleJsonConfig()
        businessModuleList = []
        for item in self.__initialConfig.moduleNameList:
            moudle_item = self.__moduleConfig.get_item(item)
            if (
                moudle_item.type == ModuleItemType.Module
                or moudle_item.type == ModuleItemType.Lib
                or moudle_item.type == ModuleItemType.Plugin
            ):
                businessModuleList.append(item)
        return businessModuleList



import codecs
import re
from tdf_tools.tools.print import Print


class RegularTool:

    __replace_sign = r"#@^&#%&%*$#"

    # 删除埋点
    def delete_track(content: str) -> str:
        m = re.compile(r"TDFAnalytics.track.track\([^\(]*?\);")
        outtmp = re.sub(m, "", content)
        return outtmp

    # 删除备注
    def delete_remark(content: str) -> str:
        m = re.compile(r"//.*")
        outtmp = re.sub(m, "", content)
        return outtmp

    # 删除弃用
    def delete_deprecated(content: str) -> str:
        m = re.compile(r"@Deprecated\(.*?\)")
        outtmp = re.sub(m, "", content)
        return outtmp

    # 删除 @router 相关的文案
    def delete_router(content: str) -> str:
        m = re.compile(r"@TZRouter\([^\(]*?\)")
        outtmp = re.sub(m, "", content)
        return outtmp

    # 寻找带 .intl 后缀的文本，匹配出来是不带 "" 或者 '' 的字符
    def find_intl_str(content: str) -> list[str]:
        matchs_d = RegularTool.__match_str(
            content,
            r"\"",
            r"(?<=\")[^\"\f\n\r\t\v]*?[\u4E00-\u9FA5][^\"\f\n\r\t\v]*?(?=\"\s*\.intl)",
        )
        # matchs_s = RegularTool.__match_str(
        #     content,
        #     r"\'",
        #     r"(?<=\')[^\'\f\n\r\t\v]*?[\u4E00-\u9FA5][^\'\f\n\r\t\v]*?(?=\'\s*\.intl)",
        # )
        return matchs_d

    # 删除带 .intl 后缀的文本
    def delete_intl_str(content: str) -> str:
        outtmp = RegularTool.__delete_str(
            content,
            r"\"",
            r'"[^\"\f\n\r\t\v]*?[\u4E00-\u9FA5][^\"\f\n\r\t\v]*?"\s*\.intl',
        )
        # outtmp = RegularTool.__delete_str(
        #     outtmp,
        #     r"\'",
        #     r"'[^\'\f\n\r\t\v]*?[\u4E00-\u9FA5][^\'\f\n\r\t\v]*?'\s*\.intl",
        # )
        return outtmp

    # 寻找 intl 的单引号字符串
    def find_apostrophe_strs(content: str) -> list[str]:
        return RegularTool.find_apostrophe_intl(
            content
        ) + RegularTool.find_apostrophe_chinese(content)

    # 寻找 intl 的单引号字符串
    def find_apostrophe_intl(content: str) -> list[str]:
        matchs_s = RegularTool.__match_str(
            content,
            r"\'",
            r"(?<=\')[^\'\f\n\r\t\v]*?[\u4E00-\u9FA5][^\'\f\n\r\t\v]*?(?=\'\s*\.intl)",
        )
        return matchs_s

    # 寻找没有国际化的单引号字符串
    def find_apostrophe_chinese(content: str) -> list[str]:
        matchs_s = RegularTool.__match_str(
            content,
            r"\'",
            r"'[^\'\f\n\r\t\v]*?[\u4E00-\u9FA5][^\'\f\n\r\t\v]*?'(?!\.intl)",
        )
        matchs_s = list(map(lambda x: x.strip(r"'"), matchs_s))
        return matchs_s

    # 寻找没国际化的中文字符串，匹配出来是不带 "" 或者 '' 的字符
    def find_chinese_str(content: str) -> list[str]:
        matchs_d = RegularTool.__match_str(
            content,
            r"\"",
            r'"[^\"\f\n\r\t\v]*?[\u4E00-\u9FA5][^\"\f\n\r\t\v]*?"(?!\.intl)',
        )
        matchs_d = list(map(lambda x: x.strip(r'"'), matchs_d))
        # matchs_s = RegularTool.__match_str(
        #     content,
        #     r"\'",
        #     r"'[^\'\f\n\r\t\v]*?[\u4E00-\u9FA5][^\'\f\n\r\t\v]*?'(?!\.intl)",
        # )
        # matchs_s = list(map(lambda x: x.strip(r"'"), matchs_s))
        return matchs_d

    # 替换单引号成双引号
    def replace_apostrophe_strs(content: str, strs: list[str]) -> str:
        for str in strs:
            m_str = r"'{0}'".format(str)
            content = content.replace(m_str, '"' + str + '"')

        return content

    # 批量替换 .intl
    def replace_chinese_strs(content: str, strs: list[str]) -> str:

        for str in strs:
            m_str = r'"{0}"'.format(str)
            content = content.replace(m_str, m_str + ".intl")

        return content

    # 替换掉多个 .intl 结尾的字符串
    def replace_multi_intl(content: str) -> str:
        def __delete_intl(matched):
            # 删除多余的 .intl
            tempstr: str = matched.group()  # 取查找到的字符/串
            c_str = tempstr.split(".intl")[0]
            tempstr = c_str + ".intl"  # 格式化7
            return tempstr

        q_sign = r"\""
        content = content.replace(q_sign, RegularTool.__replace_sign)
        m = re.compile(
            r'"[^\"\f\n\r\t\v]*?[\u4E00-\u9FA5][^\"\f\n\r\t\v]*?"\s*.intl[\.intl]*\.intl'
        )
        content = re.sub(m, __delete_intl, content)
        content = content.replace(RegularTool.__replace_sign, q_sign)
        return content

    # 没国际化的中文字符串 追加 .intl
    # def replace_chinese_str(content: str, old_str: str) -> str:

    #     q_sign = r"\""
    #     content = content.replace(q_sign, RegularTool.__replace_sign)
    #     m = re.compile(r'"[^\"\f\n\r\t\v]*?[\u4E00-\u9FA5][^\"\f\n\r\t\v]*?"(?!\.intl)')
    #     content: str = re.sub(m, RegularTool.__append_Suffix, content)
    #     content = content.replace(RegularTool.__replace_sign, q_sign)

    # s_sign = r"\'"
    # content = content.replace(s_sign, RegularTool.__replace_sign)
    # m = re.compile(r"'[^\'\f\n\r\t\v]*?[\u4E00-\u9FA5][^\'\f\n\r\t\v]*?'(?!\.intl)")
    # content = re.sub(m, RegularTool.__append_Suffix, content)
    # content = content.replace(RegularTool.__replace_sign, s_sign)

    # return content

    # def __append_Suffix(matched):
    #     # 找到字母，把原字母 添加 .intl
    #     tempstr = matched.group()  # 取查找到的字符/串
    #     tempstr = tempstr + ".intl"  # 格式化
    #     return tempstr

    # 删除匹配的字符串
    def __delete_str(content: str, sign: str, pattern: str) -> str:
        content = content.replace(sign, RegularTool.__replace_sign)
        m = re.compile(pattern)
        outtmp = re.sub(m, "", content)
        return outtmp

    # 匹配 字符串，无法处理的符号先替换，然后再处理
    def __match_str(content: str, sign: str, pattern: str) -> list[str]:
        match_strs = []
        content = content.replace(sign, RegularTool.__replace_sign)
        matchs: list[str] = re.findall(pattern, content)
        for m in matchs:
            new_str = m.replace(RegularTool.__replace_sign, sign)
            match_strs.append(new_str)
        return match_strs

    # 寻找 intl 的 import 字符
    def find_intl_imports(content: str) -> list[str]:
        pattern = r"import '.*_i18n.dart';"
        matchs = re.findall(pattern, content)
        return matchs

    # 替换 intl 的 import
    def replace_intl_imports(content: str, replace_str: str) -> str:
        m = re.compile(r"import '.*_i18n.dart';")
        outtmp = re.sub(m, replace_str, content)
        return outtmp

    # 去掉转义符
    def decode_escapes(s) -> str:
        ESCAPE_SEQUENCE_RE = re.compile(
            r"""
        ( \\U........      # 8-digit hex escapes
        | \\u....          # 4-digit hex escapes
        | \\x..            # 2-digit hex escapes
        | \\[0-7]{1,3}     # Octal escapes
        | \\N\{[^}]+\}     # Unicode characters by name
        | \\[\\'"abfnrtv]  # Single-character escapes
        )""",
            re.UNICODE | re.VERBOSE,
        )

        def decode_match(match):
            return codecs.decode(match.group(0), "unicode-escape")

        return ESCAPE_SEQUENCE_RE.sub(decode_match, s)



import os
from tdf_tools.tools.env import EnvTool
from tdf_tools.tools.print import Print
from ruamel import yaml


class ShellDir:
    def __getcwd():
        _workspace = EnvTool.workspace()
        if _workspace:
            return _workspace
        else:
            return os.getcwd()

    # 目录校验，确保只能在壳下执行tdf_tools
    def dirInvalidate():
        if EnvTool.is_debug():
            pass
        else:
            try:
                with open("pubspec.yaml", encoding="utf-8") as f:
                    doc = yaml.round_trip_load(f)
                    if isinstance(doc, dict) and doc.__contains__("flutter"):
                        if (
                            isinstance(doc["flutter"], dict)
                            and doc["flutter"].__contains__("module") is not True
                        ):
                            Print.error("当前不是壳工程目录，禁止执行tdf_tools命令")
                    f.close()
            except IOError:
                Print.error("当前不是壳工程目录，禁止执行tdf_tools命令")

    def getShellDir() -> str:
        return ShellDir.__getcwd()

    # 进入到壳内
    def goInShellDir():
        __path = ShellDir.__getcwd()
        if os.path.exists(__path):
            os.chdir(__path)
        else:
            Print.error(__path + "路径不存在")

    # 进入到壳的 libs
    def goInShellLibDir():
        path = ShellDir.__getcwd() + "/lib"
        if os.path.exists(path):
            os.chdir(path)
        else:
            Print.error(path + "路径不存在")

    # 获取指定模块的目录
    def getModuleDir(module: str) -> str:
        return ShellDir.__getcwd() + "/../.tdf_flutter/" + module

    # 进入到指定模块内
    def goInModuleDir(module: str):
        module_path = ShellDir.getModuleDir(module)
        if os.path.exists(module_path):
            os.chdir(module_path)
        else:
            Print.error(module_path + "路径不存在")

    # 获取指定模块的 lib 目录
    def getModuleLibDir(module: str) -> str:
        return ShellDir.__getcwd() + "/../.tdf_flutter/" + module + "/lib"

    # 进入到指定模块 Lib 内
    def goInModuleLibDir(module: str):
        module_path = ShellDir.getModuleLibDir(module)
        if os.path.exists(module_path):
            os.chdir(module_path)
        else:
            Print.error(module_path + "路径不存在")

    # 获取到指定模块 tdf_intl 路径
    def getInModuleIntlDir(module: str):
        return ShellDir.__getcwd() + "/../.tdf_flutter/" + module + "/lib/tdf_intl"

    # 进入到指定模块 tdf_intl 内
    def goInModuleIntlDir(module: str):
        module_path = ShellDir.getInModuleIntlDir(module)
        if os.path.exists(module_path):
            os.chdir(module_path)
        else:
            Print.error(module_path + "路径不存在")

    # 进入.tdf_flutter文件夹
    def getInTdfFlutterDir():
        return ShellDir.getShellDir() + "/../.tdf_flutter"

    # 进入.tdf_flutter文件夹
    def goInTdfFlutterDir():
        __path = ShellDir.getInTdfFlutterDir()
        if not os.path.exists(__path):
            os.mkdir(__path)
        os.chdir(__path)

    # 进入缓存文件目录
    def goTdfCacheDir():
        ShellDir.goInShellDir()
        if os.path.exists("tdf_cache"):
            os.chdir("tdf_cache")
        elif not os.path.exists("tdf_cache"):
            create = input("当前目录没有找到tdf_cache缓存文件夹，是否创建？(y/n):")
            if create == "y":
                os.mkdir("tdf_cache")
            else:
                Print.error("Oh,it's disappointing.")
                exit(1)

    # 获取模块名
    def getModuleNameFromYaml(yaml_path: str) -> str:
        with open(yaml_path, "r", encoding="utf-8") as rF:
            dic = yaml.round_trip_load(rF.read())
            if dic is not None and dic.__contains__("name"):
                shellModule = dic["name"]
                return shellModule
            else:
                Print.error("读取壳模块模块名失败，请确保壳模块的pubspec.yaml配置了name属性")



import json
import os
import shutil

from tdf_tools.tools.gitlab.python_gitlab_api import GitlabAPI
from tdf_tools.tools.shell_dir import ShellDir


class CLIJsonConfig:
    # 写入项目环境配置文件
    def saveInConfig(featureBranch: str, shellModule: str, moduleList: list):
        ShellDir.goInShellDir()
        if os.path.exists("tdf_cache") is not True:
            os.mkdir("tdf_cache")
        os.chdir("tdf_cache")

        with open("initial_config.json", "w", encoding="utf-8") as wf:
            initialDic = dict()
            initialDic["featureBranch"] = featureBranch
            initialDic["shellName"] = shellModule
            initialDic["moduleNameList"] = moduleList
            wf.write(json.dumps(initialDic, indent=2))
            wf.close()

    # 获取模块信息配置文件
    def getModuleConfig():
        ShellDir.goInShellDir()
        if os.path.exists("tdf_cache") is not True:
            os.mkdir("tdf_cache")
        os.chdir("tdf_cache")

        # 不存在，则拉取
        jsonData = dict
        if os.path.exists("module_config.json") is not True:
            CLIJsonConfig.__initModuleConfigJson()

        with open("module_config.json", "r", encoding="utf-8") as rf:
            jsonData = json.loads(rf.read())
            rf.close()
            return jsonData

    # 初始化模块信息配置json文件
    def __initModuleConfigJson():
        gitlabApi = GitlabAPI()
        moduleJson = gitlabApi.getModuleConfigJson()

        with open("module_config.json", "w+", encoding="utf-8") as wF:
            wF.write(json.dumps(moduleJson, indent=2))
            wF.close()

    # 更新flutter模块配置信息
    def updateModuleConfig():
        ShellDir.goTdfCacheDir()
        if os.path.exists("module_config.json"):
            os.remove("module_config.json")

        if os.path.exists("flutter_module_config"):
            shutil.rmtree(r"flutter_module_config")

        os.system(
            "git clone git@git.2dfire.net:app/flutter/tools/flutter_module_config.git"
        )
        os.chdir("flutter_module_config")
        # 请求更新gitlab上的模块配置信息
        CLIJsonConfig.requestUpdateGitlabModuleConfig()

        ShellDir.goTdfCacheDir()
        if os.path.exists("flutter_module_config"):
            shutil.rmtree(r"flutter_module_config")

        CLIJsonConfig.__initModuleConfigJson()

    # 更新模块配置信息
    def requestUpdateGitlabModuleConfig():
        FLUTTER_GROUP_ID = "1398"  # Flutter仓库组

        HPP_FLUTTER_GROUP_ID = "1489"  # 火拼拼的Flutter仓库组
        FLUTTER_REPOSITORY_GROUP_IDS = [FLUTTER_GROUP_ID, HPP_FLUTTER_GROUP_ID]

        # start
        projectInfo = dict()

        api = GitlabAPI()

        for groupId in FLUTTER_REPOSITORY_GROUP_IDS:
            groupProjectList = api.get_all_projects_in_group(groupId)
            for project in groupProjectList:
                tup = api.getContent(project.id, project.name)
                if tup[0] == True:
                    print(
                        "{0}, {1}, {2}, {3}".format(
                            tup[1],
                            project.id,
                            project.ssh_url_to_repo,
                            project.namespace["name"],
                        )
                    )
                    projectInfo[tup[1]] = dict()
                    projectInfo[tup[1]]["id"] = project.id
                    projectInfo[tup[1]]["git"] = project.ssh_url_to_repo
                    projectInfo[tup[1]]["type"] = project.namespace["name"]

        ShellDir.goTdfCacheDir()
        os.chdir("flutter_module_config")
        file = "module_config.json"
        if os.path.exists(file):
            os.remove(file)
        f = open(file, "w+")
        f.write(json.dumps(projectInfo, indent=2))
        f.close()

        os.system("git add .")
        os.system("git commit -m '更新模块git信息配置文件'")
        os.system("git push")
